@@ -7,7 +7,7 @@ from google.cloud import bigquery
 from google.oauth2 import service_account
 import requests
 import pandas as pd
-from pandas import DataFrame
+from pandas import _DataFrame
 from pandas.io.json import json_normalize
 from cryptography.fernet import Fernet
 
@@ -218,7 +218,7 @@ class CommonOperations:
             raise ex
 
     def convertdictionarytoDataFrame(self, dictionaryData, schema):
-        dataFrame = DataFrame.from_dict(dictionaryData)
+        dataFrame = _DataFrame.from_dict(dictionaryData)
 
         for sc in schema:
             if sc.field_type == 'INTEGER':
